Module binary

Module binary 

Binary tensor operations (add, sub, mul, div).

Modules

dispatch_float
dispatch_int

Enums

BinaryOp
Operation type for SIMD dispatch.

Functions

binary_op
Apply a binary operation element-wise to two tensors.
binary_op_typed
Binary operation with in-place optimization for Pod types.
int_binary_op
Apply a binary operation element-wise to two integer tensors.
int_scalar_op
Apply a scalar operation to each element of an integer tensor. Note: scalar is truncated to target dtype (matches PyTorch).
scalar_op
Apply a scalar operation to each element of a tensor.
scalar_op_typed