pub fn broadcast_binary(
lhs: HostTensor,
rhs: HostTensor,
) -> (HostTensor, HostTensor)Expand description
Broadcast two tensors to the same shape for binary operations.
pub fn broadcast_binary(
lhs: HostTensor,
rhs: HostTensor,
) -> (HostTensor, HostTensor)Broadcast two tensors to the same shape for binary operations.