pub struct HostQTensor { /* private fields */ }Expand description
Quantized tensor for the Flex backend.
Stores quantized i8 values in the tensor and keeps scales separately for efficient dequantization without reparsing bytes.
Implementations
Sourceimpl HostQTensor
impl HostQTensor
Sourcepub fn new(tensor: HostTensor, scheme: QuantScheme, scales: Vec<f32>) -> Self
pub fn new(tensor: HostTensor, scheme: QuantScheme, scales: Vec<f32>) -> Self
Create a new quantized tensor.
The tensor must store i8 data and scales must match the quantization parameter shape.
Sourcepub fn tensor(&self) -> &HostTensor
pub fn tensor(&self) -> &HostTensor
Get the underlying tensor.