pub fn sort(tensor: HostTensor, dim: usize, descending: bool) -> HostTensorExpand description
Sort elements along a dimension, returning the sorted tensor.
pub fn sort(tensor: HostTensor, dim: usize, descending: bool) -> HostTensorSort elements along a dimension, returning the sorted tensor.