Binary tensor operations (add, sub, mul, div).
Modules
Enums
- Binary
Op - Operation type for SIMD dispatch.
Functions
- binary_
op - Apply a binary operation element-wise to two tensors.
- binary_
op_ typed - Binary operation with in-place optimization for Pod types.
- int_
binary_ op - Apply a binary operation element-wise to two integer tensors.
- int_
scalar_ op - Apply a scalar operation to each element of an integer tensor. Note: scalar is truncated to target dtype (matches PyTorch).
- scalar_
op - Apply a scalar operation to each element of a tensor.
- scalar_
op_ typed